@@ -67,6 +67,7 @@ def find_breaks(nums):
     return breaks
 
 def align(RCI,FIRST,cut_off=0.5,quiet=False):
+    quit_lowseqID = 0
     if len(RCI['resn']) <= len(FIRST['resn']): # "a" is always the shorter seq
         a = RCI['resn']
         b = FIRST['resn']
@@ -115,7 +116,7 @@ def align(RCI,FIRST,cut_off=0.5,quiet=False):
         num_resn = len([i for i in FIRST['resn'] if i != 'XXX'])
         if max_score_N < cut_off * num_resn:
             check_quiet_print(quiet,'sequence identity ('+str(round(100*max_score_N/num_resn,1))+'%) is below cut-off ('+str(100*cut_off)+'%), skipping')
-            quit()
+            quit_lowseqID = 1
     else:
         if len(RCI['resi']) <= len(FIRST['resi']):
             for r in RCI:
@@ -132,9 +133,9 @@ def align(RCI,FIRST,cut_off=0.5,quiet=False):
         num_resn = len([i for i in FIRST['resn'] if i != 'XXX'])
         if max_score_C < cut_off * num_resn:
             check_quiet_print(quiet,'sequence identity ('+str(round(100*max_score_C/num_resn,1))+'%) is below cut-off ('+str(100*cut_off)+'%), skipping')
-            quit()
+            quit_lowseqID = 1
     RCI['resi'] = FIRST['resi']
-    return RCI, FIRST
+    return RCI, FIRST, quit_lowseqID
 
 def trim(res1,res2): # lazy variable names fix this!
     s = 0
@@ -359,134 +360,136 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
     RCI = fix_missing_res(RCI,0,quiet=quiet)
 
     # align
-    RCI,FIRST = align(RCI,FIRST,quiet=quiet)
+    RCI,FIRST,quit_lowseqID = align(RCI,FIRST,quiet=quiet)
 
-    # trim - look for where first 3 residues and last 3 residues in aligned RCI/FIRST output are and make these the beginning/end
-    start,end = trim(RCI['resn'],FIRST['resn'])
-    for r in RCI:
-        RCI[r] = RCI[r][start:end] 
-    for f in FIRST:
-        FIRST[f] = FIRST[f][start:end] 
+    if quit_lowseqID == 0:
 
-    # rescale
-    FIRST['score'] = rescale_FIRST(FIRST)
-    #RCI['score'] = rescale_RCI(RCI['score']) # RCI now arrives rescaled
+        # trim - look for where first 3 residues and last 3 residues in aligned RCI/FIRST output are and make these the beginning/end
+        start,end = trim(RCI['resn'],FIRST['resn'])
+        for r in RCI:
+            RCI[r] = RCI[r][start:end] 
+        for f in FIRST:
+            FIRST[f] = FIRST[f][start:end] 
 
-    # various stats
-    RCI_nan = [i for i,x in enumerate(RCI['score']) if np.isnan(x)]
-    FIRST_nan = [i for i,x in enumerate(FIRST['score']) if np.isnan(x)]
-    RCI_noRC = [x for i,x in enumerate(RCI['score']) if i not in FIRST_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC']
-    FIRST_noRC = [x for i,x in enumerate(FIRST['score']) if i not in RCI_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC']
+        # rescale
+        FIRST['score'] = rescale_FIRST(FIRST)
+        #RCI['score'] = rescale_RCI(RCI['score']) # RCI now arrives rescaled
 
-    RMSD_noRC =  calc_RMSD(RCI_noRC,FIRST_noRC)
-    RMSD_score = 100.0 - percentileofscore(benchmarks['rmsd'],RMSD_noRC)
+        # various stats
+        RCI_nan = [i for i,x in enumerate(RCI['score']) if np.isnan(x)]
+        FIRST_nan = [i for i,x in enumerate(FIRST['score']) if np.isnan(x)]
+        RCI_noRC = [x for i,x in enumerate(RCI['score']) if i not in FIRST_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC']
+        FIRST_noRC = [x for i,x in enumerate(FIRST['score']) if i not in RCI_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC']
 
-    if all_same(FIRST_noRC) or all_same(RCI_noRC):
-        spearman_noRC = np.nan
-        corr_score = np.nan
-        check_quiet_print(quiet,'*WARNING Spearman correlation coefficient cannot be determined, setting correlation score to NaN * ',end='')
-    else:
-        spearman_noRC = spearmanr(RCI_noRC,FIRST_noRC)[0]
-        corr_score = percentileofscore(benchmarks['corr'],spearman_noRC)
+        RMSD_noRC =  calc_RMSD(RCI_noRC,FIRST_noRC)
+        RMSD_score = 100.0 - percentileofscore(benchmarks['rmsd'],RMSD_noRC)
 
-    if run_CYRANGE == '1':
-        RCI_noRC_welldefined = [x for i,x in enumerate(RCI['score']) if i not in FIRST_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC' and FIRST['welldefined'][i]=='1']
-        FIRST_noRC_welldefined = [x for i,x in enumerate(FIRST['score']) if i not in RCI_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC' and FIRST['welldefined'][i]=='1']
-        
-        RMSD_noRC_welldefined =  calc_RMSD(RCI_noRC_welldefined,FIRST_noRC_welldefined)
-        RMSD_score_welldefined = 100.0 - percentileofscore(benchmarks['rmsd_welldefined'],RMSD_noRC_welldefined)
-        #RMSD_score_welldefined = 100.0 - percentileofscore(benchmarks['rmsd_welldefined'],RMSD_noRC_welldefined)
-
-        if all_same(FIRST_noRC_welldefined) or all_same(RCI_noRC_welldefined):
-            spearman_noRC_welldefined = np.nan
-            corr_score_welldefined = np.nan
-            check_quiet_print(quiet,'*WARNING Spearman correlation coefficient for well-defined residues cannot be determined, setting correlation score to NaN * ',end='')
+        if all_same(FIRST_noRC) or all_same(RCI_noRC):
+            spearman_noRC = np.nan
+            corr_score = np.nan
+            check_quiet_print(quiet,'*WARNING Spearman correlation coefficient cannot be determined, setting correlation score to NaN * ',end='')
         else:
-            spearman_noRC_welldefined = spearmanr(RCI_noRC_welldefined,FIRST_noRC_welldefined)[0]
-            corr_score_welldefined = percentileofscore(benchmarks['corr_welldefined'],spearman_noRC_welldefined)
-            #corr_score_welldefined = percentileofscore(benchmarks['corr_welldefined'],spearman_noRC_welldefined)
+            spearman_noRC = spearmanr(RCI_noRC,FIRST_noRC)[0]
+            corr_score = percentileofscore(benchmarks['corr'],spearman_noRC)
+
+        if run_CYRANGE == '1':
+            RCI_noRC_welldefined = [x for i,x in enumerate(RCI['score']) if i not in FIRST_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC' and FIRST['welldefined'][i]=='1']
+            FIRST_noRC_welldefined = [x for i,x in enumerate(FIRST['score']) if i not in RCI_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC' and FIRST['welldefined'][i]=='1']
+            
+            RMSD_noRC_welldefined =  calc_RMSD(RCI_noRC_welldefined,FIRST_noRC_welldefined)
+            RMSD_score_welldefined = 100.0 - percentileofscore(benchmarks['rmsd_welldefined'],RMSD_noRC_welldefined)
+            #RMSD_score_welldefined = 100.0 - percentileofscore(benchmarks['rmsd_welldefined'],RMSD_noRC_welldefined)
+
+            if all_same(FIRST_noRC_welldefined) or all_same(RCI_noRC_welldefined):
+                spearman_noRC_welldefined = np.nan
+                corr_score_welldefined = np.nan
+                check_quiet_print(quiet,'*WARNING Spearman correlation coefficient for well-defined residues cannot be determined, setting correlation score to NaN * ',end='')
+            else:
+                spearman_noRC_welldefined = spearmanr(RCI_noRC_welldefined,FIRST_noRC_welldefined)[0]
+                corr_score_welldefined = percentileofscore(benchmarks['corr_welldefined'],spearman_noRC_welldefined)
+                #corr_score_welldefined = percentileofscore(benchmarks['corr_welldefined'],spearman_noRC_welldefined)
 
 
-    av_perc_shifts = int(round(np.nanmean([RCI['shifts'][i[0]] for i in enumerate(RCI['resi']) if not np.isnan(i[1])])*100.0))
+        av_perc_shifts = int(round(np.nanmean([RCI['shifts'][i[0]] for i in enumerate(RCI['resi']) if not np.isnan(i[1])])*100.0))
 
-    if av_perc_shifts < 75:
-        av_perc_shifts_out = str(av_perc_shifts)+' (RCI less reliable!)'
-        check_quiet_print(quiet,'*WARNING chemical shift completeness (' + str(av_perc_shifts) +'%)' +' is below recommended minimum (75%), RCI may be unreliable* DONE')
-    else:
-        av_perc_shifts_out = str(av_perc_shifts)
-        check_quiet_print(quiet,'DONE')
-        
-    # write output file
-    if not os.path.exists(output_dir):
-        os.makedirs(output_dir+'figs')
-        os.makedirs(output_dir+'out')
+        if av_perc_shifts < 75:
+            av_perc_shifts_out = str(av_perc_shifts)+' (RCI less reliable!)'
+            check_quiet_print(quiet,'*WARNING chemical shift completeness (' + str(av_perc_shifts) +'%)' +' is below recommended minimum (75%), RCI may be unreliable* DONE')
+        else:
+            av_perc_shifts_out = str(av_perc_shifts)
+            check_quiet_print(quiet,'DONE')
+            
+        # write output file
+        if not os.path.exists(output_dir):
+            os.makedirs(output_dir+'figs')
+            os.makedirs(output_dir+'out')
 
-    RCI_FIRST_out = open(output_dir+'out/'+PDB_ID+'_'+SHIFT_ID+'.out','w')
-    for i in enumerate(FIRST['resi']):
+        RCI_FIRST_out = open(output_dir+'out/'+PDB_ID+'_'+SHIFT_ID+'.out','w')
+        for i in enumerate(FIRST['resi']):
 
-        ss = str(FIRST['ss'][i[0]])
-        wd = str(FIRST['welldefined'][i[0]])
-        if ss == 'nan':
-            ss = '.'
-        if wd == 'nan':
-            wd = '.'
+            ss = str(FIRST['ss'][i[0]])
+            wd = str(FIRST['welldefined'][i[0]])
+            if ss == 'nan':
+                ss = '.'
+            if wd == 'nan':
+                wd = '.'
 
-        if FIRST['resn'][i[0]] != 'XXX':
-            RCI_FIRST_out.write('{:>5}'.format(FIRST['resi'][i[0]])+' '+'{:<4}'.format(FIRST['resn'][i[0]])+'{:<23.20f}'.format(float(RCI['score'][i[0]]))+'{:<23.20f}'.format(float(FIRST['score'][i[0]]))+ss+' '+wd+' '+'{:<5.2f}'.format(RCI['shifts'][i[0]])+'{:<10}'.format(RCI['shift_types'][i[0]])+'\n')
-    RCI_FIRST_out.close()
+            if FIRST['resn'][i[0]] != 'XXX':
+                RCI_FIRST_out.write('{:>5}'.format(FIRST['resi'][i[0]])+' '+'{:<4}'.format(FIRST['resn'][i[0]])+'{:<23.20f}'.format(float(RCI['score'][i[0]]))+'{:<23.20f}'.format(float(FIRST['score'][i[0]]))+ss+' '+wd+' '+'{:<5.2f}'.format(RCI['shifts'][i[0]])+'{:<10}'.format(RCI['shift_types'][i[0]])+'\n')
+        RCI_FIRST_out.close()
 
-    # append to scores.out
-    scores = open(output_dir+'scores.out','a+')
-    if run_CYRANGE == '1':
-        scores.write('PDB: '+ '{:<11}'.format(PDB_ID) + ' SHIFTS: '+ '{:<11}'.format(SHIFT_ID) + ' SHIFT%: '+ '{:3}'.format(av_perc_shifts) + ' Corr: '+ '{: 5.3f}'.format(spearman_noRC) + ' CorrScore: '+ '{:4.1f}'.format(round(corr_score,1)) + ' RMSD: '+ '{:4.3f}'.format(RMSD_noRC) + ' RMSDScore: '+ '{:4.1f}'.format(round(RMSD_score,1))+ ' Corr-WD: '+ '{: 5.3f}'.format(spearman_noRC_welldefined)+' CorrScore-WD: '+ '{:4.1f}'.format(round(corr_score_welldefined,1)) + ' RMSD-WD: '+ '{:4.3f}'.format(RMSD_noRC_welldefined) + ' RMSDScore-WD: '+ '{:4.1f}'.format(round(RMSD_score_welldefined,1))+'\n')
-    else:
-        scores.write('PDB: '+ '{:<11}'.format(PDB_ID) + ' SHIFTS: '+ '{:<11}'.format(SHIFT_ID) + ' SHIFT%: '+ '{:3}'.format(av_perc_shifts) + ' Corr: '+ '{: 5.3f}'.format(spearman_noRC) + ' CorrScore: '+ '{:4.1f}'.format(round(corr_score,1)) + ' RMSD: '+ '{:4.3f}'.format(RMSD_noRC)+ ' RMSDScore: '+ '{:4.1f}'.format(round(RMSD_score,1))+ '\n')
-    scores.close()
+        # append to scores.out
+        scores = open(output_dir+'scores.out','a+')
+        if run_CYRANGE == '1':
+            scores.write('PDB: '+ '{:<11}'.format(PDB_ID) + ' SHIFTS: '+ '{:<11}'.format(SHIFT_ID) + ' SHIFT%: '+ '{:3}'.format(av_perc_shifts) + ' Corr: '+ '{: 5.3f}'.format(spearman_noRC) + ' CorrScore: '+ '{:4.1f}'.format(round(corr_score,1)) + ' RMSD: '+ '{:4.3f}'.format(RMSD_noRC) + ' RMSDScore: '+ '{:4.1f}'.format(round(RMSD_score,1))+ ' Corr-WD: '+ '{: 5.3f}'.format(spearman_noRC_welldefined)+' CorrScore-WD: '+ '{:4.1f}'.format(round(corr_score_welldefined,1)) + ' RMSD-WD: '+ '{:4.3f}'.format(RMSD_noRC_welldefined) + ' RMSDScore-WD: '+ '{:4.1f}'.format(round(RMSD_score_welldefined,1))+'\n')
+        else:
+            scores.write('PDB: '+ '{:<11}'.format(PDB_ID) + ' SHIFTS: '+ '{:<11}'.format(SHIFT_ID) + ' SHIFT%: '+ '{:3}'.format(av_perc_shifts) + ' Corr: '+ '{: 5.3f}'.format(spearman_noRC) + ' CorrScore: '+ '{:4.1f}'.format(round(corr_score,1)) + ' RMSD: '+ '{:4.3f}'.format(RMSD_noRC)+ ' RMSDScore: '+ '{:4.1f}'.format(round(RMSD_score,1))+ '\n')
+        scores.close()
 
-    # plot figs
-    #plot(RCI,FIRST)
+        # plot figs
+        #plot(RCI,FIRST)
 
-    helices_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'H'] # FIRST resi can be nan!
-    helices_y = [1.04]*len(helices_x)
-    strands_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'E']
-    strands_y = [1.04]*len(strands_x)
+        helices_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'H'] # FIRST resi can be nan!
+        helices_y = [1.04]*len(helices_x)
+        strands_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'E']
+        strands_y = [1.04]*len(strands_x)
 
-    RC_residues_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['resi']) if RCI['shift_types'][i[0]] == 'RC']
-    if len(RC_residues_x) > 0:
-        RC_residues_y = [1.02]*len(RC_residues_x)
-        plt.scatter(RC_residues_x,RC_residues_y,color='black',marker="x",s=5)
+        RC_residues_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['resi']) if RCI['shift_types'][i[0]] == 'RC']
+        if len(RC_residues_x) > 0:
+            RC_residues_y = [1.02]*len(RC_residues_x)
+            plt.scatter(RC_residues_x,RC_residues_y,color='black',marker="x",s=5)
 
-    if run_CYRANGE == '1':
-        welldefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '1'] # FIRST resi can be nan!
-        welldefined_y = [1.06]*len(welldefined_x)
-        illdefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '0'] # FIRST resi can be nan!
-        illdefined_y = [1.06]*len(illdefined_x)
-        plt.scatter(welldefined_x,welldefined_y,color='limegreen',s=2)
-        plt.scatter(illdefined_x,illdefined_y,color='grey',s=2)
+        if run_CYRANGE == '1':
+            welldefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '1'] # FIRST resi can be nan!
+            welldefined_y = [1.06]*len(welldefined_x)
+            illdefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '0'] # FIRST resi can be nan!
+            illdefined_y = [1.06]*len(illdefined_x)
+            plt.scatter(welldefined_x,welldefined_y,color='limegreen',s=2)
+            plt.scatter(illdefined_x,illdefined_y,color='grey',s=2)
 
-    # get range over which to plot
-    resi_range = []
-    for i in enumerate(FIRST['resi']):
-        if str(FIRST['score'][i[0]]) != 'nan' and str(RCI['score'][i[0]]) != 'nan':
-            resi_range.append(i[1])
+        # get range over which to plot
+        resi_range = []
+        for i in enumerate(FIRST['resi']):
+            if str(FIRST['score'][i[0]]) != 'nan' and str(RCI['score'][i[0]]) != 'nan':
+                resi_range.append(i[1])
 
-    plt.figure()
+        plt.figure()
 
-    plt.plot(RCI['resi'],RCI['score'])
-    plt.plot(FIRST['resi'],FIRST['score'])
-    plt.scatter(helices_x,helices_y,color='red',s=2)
-    plt.scatter(strands_x,strands_y,color='blue',s=2)
-    plt.xlabel('residue number',size=10)
-    plt.ylabel('flexibility',size=10)
-    plt.ylim(-0.025,1.075)
-    plt.xlim(min(resi_range)-5,max(resi_range)+5)
-    if run_CYRANGE == '1':
-        plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n All residues | Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score)+'\n Well-defined | Corr: '+"{:.3f}".format(spearman_noRC_welldefined)+' CorrScore: ' + "{:.1f}".format(corr_score_welldefined)+' RMSD: '+"{:.3f}".format(RMSD_noRC_welldefined)+' RMSDScore: ' + "{:.1f}".format(RMSD_score_welldefined),fontsize=10)
-    else:
-        plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score),fontsize=10)
-    plt.savefig(output_dir+'figs/'+PDB_ID+'_'+SHIFT_ID+'.png',dpi=300,bbox_inches='tight')
+        plt.plot(RCI['resi'],RCI['score'])
+        plt.plot(FIRST['resi'],FIRST['score'])
+        plt.scatter(helices_x,helices_y,color='red',s=2)
+        plt.scatter(strands_x,strands_y,color='blue',s=2)
+        plt.xlabel('residue number',size=10)
+        plt.ylabel('flexibility',size=10)
+        plt.ylim(-0.025,1.075)
+        plt.xlim(min(resi_range)-5,max(resi_range)+5)
+        if run_CYRANGE == '1':
+            plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n All residues | Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score)+'\n Well-defined | Corr: '+"{:.3f}".format(spearman_noRC_welldefined)+' CorrScore: ' + "{:.1f}".format(corr_score_welldefined)+' RMSD: '+"{:.3f}".format(RMSD_noRC_welldefined)+' RMSDScore: ' + "{:.1f}".format(RMSD_score_welldefined),fontsize=10)
+        else:
+            plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score),fontsize=10)
+        plt.savefig(output_dir+'figs/'+PDB_ID+'_'+SHIFT_ID+'.png',dpi=300,bbox_inches='tight')
 
-    plt.close()
+        plt.close()
 
 def main():
 
